@@ -1,19 +1,33 @@
-from typing import Dict, List, Optional
-
 import warnings
+from typing import Dict, List, Optional, Union
+from uuid import UUID
+
 import httpx
 
 from .channels import Channel
 from .exceptions import MirthLoginError
-from .models import ChannelList, ChannelModel, EventList, EventModel, LoginResponse
+from .models import (
+    ChannelGroup,
+    ChannelList,
+    ChannelModel,
+    ChannelStatistics,
+    ChannelStatisticsList,
+    EventList,
+    EventModel,
+    GroupList,
+    LoginResponse,
+)
 from .utils import deprecated
 
 
 class MirthAPI:
     """Class corresponding to a Mirth web API connection"""
 
-    def __init__(self, url: str, verify_ssl: bool = True) -> None:
+    def __init__(
+        self, url: str, verify_ssl: bool = True, timeout: Optional[int] = 5
+    ) -> None:
         self.base = url.rstrip("/")
+        self.timeout = timeout
 
         self._dict_constructor = dict
         self.session = httpx.AsyncClient(verify=verify_ssl)
@@ -41,6 +55,7 @@ class MirthAPI:
             httpx.Response: API response
         """
         path: str = self.base + url
+        kwargs.setdefault("timeout", self.timeout)
 
         if content_type:
             if "headers" not in kwargs:
@@ -60,6 +75,8 @@ class MirthAPI:
             httpx.Response: API response
         """
         path: str = self.base + url
+        kwargs.setdefault("timeout", self.timeout)
+
         return await self.session.get(path, **kwargs)
 
     async def login(self, user: str, password: str):
@@ -86,10 +103,6 @@ class MirthAPI:
 
     async def channel_info(self) -> List[ChannelModel]:
         """Get a list of all channel metadata on the Mirth instance.
-        Optionally search for a specific channel name.
-
-        Args:
-            name (Optional[str], optional): Channel name. Defaults to None.
 
         Returns:
             List[Channel]: List of Mirth channels
@@ -102,6 +115,17 @@ class MirthAPI:
 
         return channels.channel
 
+    async def statistics(self) -> List[ChannelStatistics]:
+        """Get a list of all channel statistics on the Mirth instance.
+
+        Returns:
+            List[Channel]: List of Mirth channel statistics
+        """
+        response = await self.get("/channels/statistics")
+
+        statistics = ChannelStatisticsList.parse_raw(response.text, content_type="xml")
+        return statistics.channel_statistics
+
     async def channels(self) -> List[Channel]:
         """Get a list of interactive Channel objects on the Mirth instance.
 
@@ -111,16 +135,30 @@ class MirthAPI:
         channel_infos = await self.channel_info()
         return [self.channel(channel.id) for channel in channel_infos]
 
-    def channel(self, id_: str) -> Channel:
+    async def groups(self) -> List[ChannelGroup]:
+        """Get a list of Channel groups on the Mirth instance.
+        Includes IDs of channels within each group.
+
+        Returns:
+            List[ChannelGroup]: List of channel groups
+        """
+        response = await self.get("/channelgroups")
+
+        groups = GroupList.parse_raw(
+            response.text, content_type="xml", force_list=("channelGroup",)
+        )
+        return groups.channel_group
+
+    def channel(self, id_: Union[str, UUID]) -> Channel:
         """Return an interactive Channel object
 
         Args:
-            id_ (str): Channel GUID/UUID
+            id_ (str, UUID): Channel GUID/UUID
 
         Returns:
             Channel: Channel object
         """
-        return Channel(self, id_)
+        return Channel(self, str(id_))
 
     async def events(
         self,
